==> pdf_viewer_plugin-2.0.0.tar.gz: lib/src/android_viewers/surface_android_pdf_viewer.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

import '../../pdf_viewer_plugin.dart';
import '../pdf_viewer_method_channel.dart';
import 'android_pdf_viewer.dart';

class SurfaceAndroidPdfViewer extends AndroidPdfViewer {
  @override
  Widget build({
    BuildContext? context,
    CreationParams? creationParams,
    Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers,
  }) {
    return PlatformViewLink(
      viewType: 'pdf_viewer_plugin',
      surfaceFactory: (
        BuildContext context,
        PlatformViewController controller,
      ) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: gestureRecognizers ?? const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: 'pdf_viewer_plugin',
          layoutDirection: TextDirection.rtl,
          creationParams: MethodChannelPdfViewerPlatform.creationParamsToMap(creationParams!),
          creationParamsCodec: const StandardMessageCodec(),
        )
          ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
          ..create();
      },
    );
  }
}

==> pdf_viewer_plugin-2.0.1.tar.gz: lib/src/android_viewers/surface_android_pdf_viewer.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

import '../../pdf_viewer_plugin.dart';
import '../pdf_viewer_method_channel.dart';
import 'android_pdf_viewer.dart';

class SurfaceAndroidPdfViewer extends AndroidPdfViewer {
  @override
  Widget build({
    BuildContext? context,
    CreationParams? creationParams,
    Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers,
  }) {
    return PlatformViewLink(
      viewType: 'pdf_viewer_plugin',
      surfaceFactory: (
        BuildContext context,
        PlatformViewController controller,
      ) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: gestureRecognizers ??
              const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: 'pdf_viewer_plugin',
          layoutDirection: TextDirection.rtl,
          creationParams: MethodChannelPdfViewerPlatform.creationParamsToMap(
              creationParams!),
          creationParamsCodec: const StandardMessageCodec(),
        )
          ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
          ..create();
      },
    );
  }
}
